@@ -17,23 +17,22 @@ db.init_app(app)
 api = Api(app)
 
 # Artists
-api.add_resource(resources.ArtistResource, '/artists',
-                 '/artists/<int:artist_id>', '/artists/<artist_slug>',
-                 endpoint='artists')
-api.add_resource(resources.ShowsResource, '/artists/<int:artist_id>/shows',
-                 '/artists/<artist_slug>/shows', endpoint='shows')
+api.add_resource(resources.ArtistResource, '/artists', '/artists/<int:id>',
+                 '/artists/<slug>', endpoint='artists')
+api.add_resource(resources.ShowsResource, '/artists/<int:id>/shows',
+                 '/artists/<slug>/shows', endpoint='shows')
 
 # Albums
-api.add_resource(resources.AlbumResource, '/albums', '/albums/<int:album_id>',
-                 '/albums/<album_slug>', endpoint='albums')
+api.add_resource(resources.AlbumResource, '/albums', '/albums/<int:id>',
+                 '/albums/<slug>', endpoint='albums')
 
 # Tracks
-api.add_resource(resources.TrackResource, '/tracks', '/tracks/<int:track_id>',
-                 '/tracks/<track_slug>', endpoint='tracks')
-api.add_resource(resources.LyricsResource, '/tracks/<int:track_id>/lyrics',
-                 '/tracks/<track_slug>/lyrics', endpoint='lyrics')
-api.add_resource(resources.ConvertResource, '/tracks/<int:track_id>/convert',
-                 '/tracks/<track_slug>/convert', endpoint='convert')
+api.add_resource(resources.TrackResource, '/tracks', '/tracks/<int:id>',
+                 '/tracks/<slug>', endpoint='tracks')
+api.add_resource(resources.LyricsResource, '/tracks/<int:id>/lyrics',
+                 '/tracks/<slug>/lyrics', endpoint='lyrics')
+api.add_resource(resources.ConvertResource, '/tracks/<int:id>/convert',
+                 '/tracks/<slug>/convert', endpoint='convert')
 
 # Other
 api.add_resource(resources.RandomResource, '/random/<resource_name>',
