@@ -14,6 +14,7 @@ class StatusCodesTestCase(unittest.TestCase):
         db_uri = 'sqlite:///%s' % self.db_path
         shiva.app.config['SQLALCHEMY_DATABASE_URI'] = db_uri
         shiva.app.config['TESTING'] = True
+        shiva.app.config['ALLOW_DELETE'] = False
         shiva.db.create_all()
         self.app = shiva.app.test_client()
 
@@ -30,7 +31,7 @@ class StatusCodesTestCase(unittest.TestCase):
         nose.eq_(rv.status_code, 200)
 
     def test_artist_404(self):
-        rv = self.app.get('/artist/1')
+        rv = self.app.get('/artists/1')
         nose.eq_(rv.status_code, 404)
 
     def test_albums(self):
@@ -38,7 +39,7 @@ class StatusCodesTestCase(unittest.TestCase):
         nose.eq_(rv.status_code, 200)
 
     def test_album_404(self):
-        rv = self.app.get('/album/1')
+        rv = self.app.get('/albums/1')
         nose.eq_(rv.status_code, 404)
 
     def test_tracks(self):
@@ -46,5 +47,9 @@ class StatusCodesTestCase(unittest.TestCase):
         nose.eq_(rv.status_code, 200)
 
     def test_track_404(self):
-        rv = self.app.get('/track/1')
+        rv = self.app.get('/tracks/1')
         nose.eq_(rv.status_code, 404)
+
+    def test_delete_not_allowed(self):
+        rv = self.app.delete('/tracks/1')
+        nose.eq_(rv.status_code, 405)
